persistent_tasmanian
---------------------------

Required: Tasmanian_, pypackaging_, scikit-build_

Note that Tasmanian can be pip installed, but currently must
use either *venv* or *--user* install.

``E.g: pip install scikit-build packaging Tasmanian --user``

.. automodule:: persistent_tasmanian
  :members:
  :undoc-members:

.. .. _Tasmanian: https://tasmanian.ornl.gov/
.. _pypackaging: https://pypi.org/project/pypackaging/
.. _scikit-build: https://scikit-build.readthedocs.io/en/latest/index.html
